@@ -31,8 +31,6 @@
 /*	VSTRING *why;
 /*	int	lflags;
 /*	unsigned *ltype;
-/*
-/*	int	dns_get_h_errno()
 /* AUXILIARY FUNCTIONS
 /*	extern int var_dns_ncache_ttl_fix;
 /*
@@ -85,10 +83,6 @@
 /*	an invalid name is reported as a DNS_INVAL result, while
 /*	malformed replies are reported as transient errors.
 /*
-/*	dns_get_h_errno() returns the last error. This deprecates
-/*	usage of the global h_errno variable. We should not rely
-/*	on that being updated.
-/*
 /*	dns_lookup_l() and dns_lookup_v() allow the user to specify
 /*	a list of resource types.
 /*
@@ -177,12 +171,6 @@
 /*	Pointer to storage for the reply RCODE value. This gives
 /*	more detailed information than DNS_FAIL, DNS_RETRY, etc.
 /* DIAGNOSTICS
-/*	If DNSSEC validation is requested but the response is not
-/*	DNSSEC validated, dns_lookup() will send a one-time probe
-/*	query as configured with the \fBdnssec_probe\fR configuration
-/*	parameter, and will log a warning when the probe response
-/*	was not DNSSEC validated.
-/* .PP
 /*	dns_lookup() returns one of the following codes and sets the
 /*	\fIwhy\fR argument accordingly:
 /* .IP DNS_OK
@@ -332,7 +320,7 @@ static struct __res_state dns_res_state;
 #endif
 
  /*
-  * To improve postscreen's allowlisting support, we need to know how long a
+  * To improve postscreen's whitelisting support, we need to know how long a
   * DNSBL "not found" answer is valid. The 2010 implementation assumed it was
   * valid for 3600 seconds. That is too long by 2015 standards.
   * 
@@ -516,7 +504,7 @@ static int dns_query(const char *name, int type, unsigned flags,
      */
 #define XTRA_FLAGS (RES_USE_EDNS0 | RES_TRUSTAD)
 
-    if (DNS_WANT_DNSSEC_VALIDATION(flags))
+    if (flags & RES_USE_DNSSEC)
 	flags |= (RES_USE_EDNS0 | RES_TRUSTAD);
 
     /*
@@ -563,8 +551,6 @@ static int dns_query(const char *name, int type, unsigned flags,
 	dns_res_state.options |= saved_options;
 	reply_header = (HEADER *) reply->buf;
 	reply->rcode = reply_header->rcode;
-	if ((reply->dnssec_ad = !!reply_header->ad) != 0)
-	    DNS_SEC_STATS_SET(DNS_SEC_FLAG_AVAILABLE);
 	if (DNS_GET_H_ERRNO(&dns_res_state) != 0) {
 	    if (why)
 		vstring_sprintf(why, "Host or domain name not found. "
@@ -618,8 +604,13 @@ static int dns_query(const char *name, int type, unsigned flags,
 
     /*
      * Initialize the reply structure. Some structure members are filled on
-     * the fly while the reply is being parsed.
+     * the fly while the reply is being parsed.  Coerce AD bit to boolean.
      */
+#if RES_USE_DNSSEC != 0
+    reply->dnssec_ad = (flags & RES_USE_DNSSEC) ? !!reply_header->ad : 0;
+#else
+    reply->dnssec_ad = 0;
+#endif
     SET_HAVE_DNS_REPLY_PACKET(reply, len);
     reply->query_start = reply->buf + sizeof(HEADER);
     reply->answer_start = 0;
@@ -706,7 +697,7 @@ static int valid_rr_name(const char *name, const char *location,
     if (valid_hostaddr(name, DONT_GRIPE)) {
 	result = PASS_NAME;
 	gripe = "numeric domain name";
-    } else if (!valid_hostname(name, DO_GRIPE | DO_WILDCARD)) {
+    } else if (!valid_hostname(name, DO_GRIPE)) {
 	result = REJECT_NAME;
 	gripe = "malformed domain name";
     } else {
@@ -937,9 +928,7 @@ static int dns_get_answer(const char *orig_name, DNS_REPLY *reply, int type,
 	    CORRUPT(DNS_RETRY);
 	if ((status = dns_get_fixed(pos, &fixed)) != DNS_OK)
 	    CORRUPT(status);
-	if (strcmp(orig_name, ".") == 0 && *rr_name == 0)
-	     /* Allow empty response name for root queries. */ ;
-	else if (!valid_rr_name(rr_name, "resource name", fixed.type, reply))
+	if (!valid_rr_name(rr_name, "resource name", fixed.type, reply))
 	    CORRUPT(DNS_INVAL);
 	if (fqdn)
 	    vstring_strcpy(fqdn, rr_name);
@@ -1027,7 +1016,7 @@ int     dns_lookup_x(const char *name, unsigned type, unsigned flags,
     /*
      * The Linux resolver misbehaves when given an invalid domain name.
      */
-    if (strcmp(name, ".") && !valid_hostname(name, DONT_GRIPE | DO_WILDCARD)) {
+    if (!valid_hostname(name, DONT_GRIPE)) {
 	if (why)
 	    vstring_sprintf(why,
 		   "Name service error for %s: invalid host or domain name",
@@ -1064,10 +1053,6 @@ int     dns_lookup_x(const char *name, unsigned type, unsigned flags,
 		(void) dns_get_answer(orig_name, &reply, T_SOA, rrlist, fqdn,
 				      cname, c_len, &maybe_secure);
 	    }
-	    if (DNS_WANT_DNSSEC_VALIDATION(flags)
-		&& !DNS_SEC_STATS_TEST(DNS_SEC_FLAG_AVAILABLE | \
-				       DNS_SEC_FLAG_DONT_PROBE))
-		dns_sec_probe(flags);		/* XXX Clobbers 'reply' */
 	    return (status);
 	}
 
@@ -1077,10 +1062,6 @@ int     dns_lookup_x(const char *name, unsigned type, unsigned flags,
 	 */
 	status = dns_get_answer(orig_name, &reply, type, rrlist, fqdn,
 				cname, c_len, &maybe_secure);
-	if (DNS_WANT_DNSSEC_VALIDATION(flags)
-	    && !DNS_SEC_STATS_TEST(DNS_SEC_FLAG_AVAILABLE | \
-				   DNS_SEC_FLAG_DONT_PROBE))
-	    dns_sec_probe(flags);		/* XXX Clobbers 'reply' */
 	switch (status) {
 	default:
 	    if (why)
@@ -1263,10 +1244,3 @@ int     dns_lookup_rv(const char *name, unsigned flags, DNS_RR **rrlist,
 	vstring_free(hpref_rtext);
     return (status);
 }
-
-/* dns_get_h_errno - get the last lookup status */
-
-int     dns_get_h_errno(void)
-{
-    return (DNS_GET_H_ERRNO(&dns_res_state));
-}
